#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include "stubs.h"

weak FontPtr
find_old_font(FSID id)
{
    return (FontPtr)NULL;
}
